Developer guide
=================

This guide is mainly directed at developers working on the ``metasyn`` package, but it may be useful for users that want
more control over the workings of the ``metasyn`` package.

.. toctree::
   :maxdepth: 1
   :caption: Sections:
   
   contributing
   overview
   distributions
   filereaders
   plugins
